Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DerefMap ¶
func DerefMap[K comparable, V any](x map[K]*V) map[K]V
DerefMap returns the value of a pointer for every element in a map.
func DerefSlice ¶
func DerefSlice[T any](x []*T) []T
DerefSlice returns the value of a pointer for every element in a slice.
func ForMap ¶
func ForMap[K comparable, V any](x map[K]V) map[K]*V
ForMap returns the pointer for every element in a map.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.